#!/bin/bash -e
# Variable to invoke the program GROMACS
#grom=/gromacs/gromacs-2020.2/bin/gmx
grom=/usr/bin/gmx
#
# Input files:
xtc=../1_traj/traj_all.xtc
tpr=../../5_MD/MPro-ligs.tpr
index=../../2_Setup/index.ndx
#

# The free energy of binding calculations are done with an in-house
# implementation of the Molecular Mechanics Poisson-Boltzmann Surface Area (MM-PBSA)
# written in python. This method can provide binding energy values
# between sections of our system i.e. protein (MPro) and ligands (13b_A and 13b_B).
# A git command is used to copy this program from its github repository, like shown below.
 
git clone https://github.com/mms-fcul/mmpbsa.git

# The following variable contains the databases folder, which is required for the MM-PBSA
# calculation using this program. These databases include:
# - the DataBase.crg and DataBase.siz files, which possess information regarding the charges
# and radii for the atoms of this system, respectively;
# - the nonbonded_itp.txt residues_rtp.txt files, which contain parameters for the nonbonded
# interactions and residue types derived from the forcefield previously used (gromos54a7);
# - the classifier.config file, which contains information for the surface area calculations.
database=Databases/  

# In newer Ubuntu versions (21.xx), it may be required the installation of a package containing "libgfortran.so.4":
sudo apt install gfortran-7

# Several python modules are required in order to successfully run the MM-PBSA calculation
# using this implementation. This includes the pandas, scipy, numpy and freesasa modules,
# which need to be installed and, if they are already installed, updated using the following commands.

pip3 install --upgrade pandas
pip3 install --upgrade scipy
pip3 install --upgrade numpy
pip3 install --upgrade freesasa

# Create a temporary folder to write the individual GRO files:
mkdir -p tmp

# The "trjconv" module is used to extract the M^pro and each ligand separately.
# Here the "-sep" flag is used to separate the trajectory into its several frames (.gro format).

$grom trjconv -f $xtc \
      -o ./tmp/frameA.gro \
      -n $index \
      -s $tpr \
      -sep  <<EOF
Protein_13b_A	    	
EOF

$grom trjconv -f $xtc \
      -o ./tmp/frameB.gro \
      -n $index \
      -s $tpr \
      -sep  <<EOF
Protein_13b_B	    	
EOF

# For each of the 1000 frames of each protein-ligand pair, an instance of the program is called.
# As input, it receives a single gro file (./tmp/frameA${gro}.gro), followed by the atom numbers
# for the beginning and end of protein, and for the beginning and end of the appropriate ligand (1 6015 6016 6072).
# Next, using the flag "-dbs", the program receives the location for all the necessary databases (which we provided).
# The "-sav" flag refers to the temporary output files location. The "-ensav" flag referes to the output file name and location,
# where the calculated energy values will be written. Finally, the "-ep" flag is the value
# for the dielectric constant used in both the calculation of the electrostatic, and polar solvation terms of the binding energy.
# A dielectric constant of 4 is usually a safe value used in this type of protocols (10.1021/ci500020m).

# Please note that this next step is very computationally expensive. You should adjust the number of frames according
# to your computational power. As an example, the 2x1000 frames calculation will take approx. 4 days in a single core
# (Intel(R) Xeon(R) CPU E5-2620 v4 @ 2.10GHz).

for gro in {0..1000} 
do
# Ligand A
    ./mmpbsa/pybinde_2021-09.py ./tmp/frameA${gro}.gro 1 6015 6016 6072 -dbs $database -sav ./tmp/ -ensav ./energies_A -ep 4
# Ligand B    
    ./mmpbsa/pybinde_2021-09.py ./tmp/frameB${gro}.gro 1 6015 6016 6072 -dbs $database -sav ./tmp/ -ensav ./energies_B -ep 4
   
done

# This implementation of the MM-PBSA method creates output files which require processing for easier handling and usage in
# further analyses. As such, a processing procedure (awk) was done in order to obtain files containg only the binding energy. 

for lig in A B
do
    awk '{print 0.1*n++, $6}' energies_$lig > energy_${lig}_processed.xvg

    # Application of a smoothing function (sliding window average)
    # The 50 points window (w=50) corresponds to sliding averages of 5 ns.
    awk -v w=50 '{n++;h1[n]=$2};END{for (i=1;i<=n-w+1;i++){s1=0; for (k=0;k<=w-1;k++) {s1+=h1[i+k]}; print (((i+w-1)-(w/2)))/10, s1/w}}' energy_${lig}_processed.xvg > energy_${lig}_average.xvg
done

# Cleanup
rm -rdf *~ *# .*~ .*# ./tmp/ LOG* mmpbsa/
